@@ -18,6 +18,9 @@ def get_page_start(page_num: int, page_size: int):
 
 class BaseDialect:
 
+    def __init__(self, engine: Engine):
+        self.engine = engine
+
     @staticmethod
     def create_insert_sql(table: str, cols: Collection[str]):
         columns, placeholders = zip(*[('{}'.format(col), '?') for col in cols])
@@ -162,15 +165,15 @@ class Dialect:
         global _DIALECT
         if _DIALECT is None:
             if Engine.MYSQL == engine:
-                _DIALECT = MySQLDialect()
+                _DIALECT = MySQLDialect(engine)
             elif Engine.POSTGRESQL == engine:
-                _DIALECT = PostgresDialect()
+                _DIALECT = PostgresDialect(engine)
             elif Engine.ORACLE == engine:
-                _DIALECT = OracleDialect()
+                _DIALECT = OracleDialect(engine)
             elif Engine.SQLITE == engine:
-                _DIALECT = SQLiteDialect()
+                _DIALECT = SQLiteDialect(engine)
             else:
-                _DIALECT = BaseDialect()
+                _DIALECT = BaseDialect(engine)
 
     @staticmethod
     def create_insert_sql(table: str, cols: Collection[str]):
@@ -201,3 +204,8 @@ class Dialect:
     def get_select_key(*args, **kwargs):
         global _DIALECT
         return _DIALECT.get_select_key(*args, **kwargs)
+
+    @staticmethod
+    def curr_engine():
+        global _DIALECT
+        return _DIALECT.engine
